# -*- coding: utf-8 -*-
import logging
import locmap.input_plugins.xldapclient

__author__ = """Thomas Oulevey"""
__email__ = 'thomas.oulevey@cern.ch'
__version__ = '2.0.0'


def retrieve_info(hostname):

    logging.debug("xldap::retrieve_info START")
    try:
        config = locmap.input_plugins.xldapclient.XldapClient()
    except:
        logging.debug("xldap::retrieve_info END")
        return 1

    result = config.host_info(hostname.hostname)
    if not result:
        logging.debug("xldap::retrieve_info END")
        return 2

    hostname.manager = result.get('mainuser_egroup', '')
    hostname.managedby = result.get('responsible_egroup', '')
    hostname.responsibles = result.get('responsibles', '')
    hostname.mainusers = result.get('mainusers', '')
    hostname.location = result.get('location', '')
    hostname.created = result.get('created', '')
    hostname.modified = result.get('modified', '')

    for login in hostname.unique_logins():
        result = config.user_info(login)
        user = hostname.add_user(login)
        user.login = ''.join(result.get('login'))
        user.name = ''.join(result.get('name'))
        user.home_dir = ''.join(result.get('home_dir'))
        user.departement = ''.join(result.get('departement'))
        user.group = ''.join(result.get('group'))
        user.section = ''.join(result.get('section'))
        user.account_type = ''.join(result.get('account_type'))
        user.email = ''.join(result.get('email'))
        user.office = ''.join(result.get('office'))
        for key in result.get('ssh_keys'):
            user.ssh_keys.add(key)
        logging.debug(user.debug())

    logging.debug(hostname.debug())
    logging.debug("xldap::retrieve_info END")
    return 0
